@@ -238,6 +238,7 @@ ppgasp <- function(design, response,trend=matrix(1,dim(response)[1],1),zero.mean
    
       COND_NUM_UB = 10^{16}  ###maximum condition number, this might be a little too large
       
+      if(lower_bound==T){
       LB_all = optimize(search_LB_prob, interval=c(-5,12), maximum = FALSE, R0=model@R0,COND_NUM_UB= COND_NUM_UB,
                         p=model@p,kernel_type=kernel_type_num,alpha=model@alpha,nugget=nugget) ###find a lower bound for parameter beta
       
@@ -248,6 +249,16 @@ ppgasp <- function(design, response,trend=matrix(1,dim(response)[1],1),zero.mean
       for( i_LB in 1:model@p){
         LB = c(LB, log(-log(LB_prob)/(max(model@R0[[i_LB]]))))    ###LB is lower bound for log beta, may consider to have it related to p
       }
+     }else{
+        ##give some empirical bound that passes the initial values if lower bound is F
+        ##could can change the first initial value if not search the bound
+        LB = NULL
+        
+        for( i_LB in 1:model@p){
+          LB = c(LB, -log(0.1)/((max(model@input[,i_LB])-min(model@input[,i_LB]))*model@p))   
+        }
+        
+      }
    
     if(lower_bound==T){
       if(model@nugget.est){
